@@ -34,6 +34,9 @@
 //! # Ok::<(), io::Error>(())
 //! ```
 
+#[cfg(feature = "async")]
+mod r#async;
+
 mod block;
 mod gz;
 mod reader;
@@ -42,6 +45,9 @@ mod writer;
 
 pub use self::{reader::Reader, virtual_position::VirtualPosition, writer::Writer};
 
+#[cfg(feature = "async")]
+pub use self::r#async::{Reader as AsyncReader, Writer as AsyncWriter};
+
 use self::block::Block;
 
 // XLEN (2)
